@@ -48,7 +48,7 @@
 #include "DwmDnsResolver.hh"
 #include "DwmDnsUtils.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/apps/dwmdns/dwmdns.cc 11271 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/trunk/apps/dwmdns/dwmdns.cc 11271 $");
 
 using namespace std;
 using namespace Dwm;
