@@ -1,5 +1,5 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/src/DwmDnsMessage.cc 10150 $
+// @(#) $DwmPath: dwm/DwmDns/trunk/classes/src/DwmDnsMessage.cc 10150 $
 // @(#) $Id: DwmDnsMessage.cc 10150 2018-01-31 05:18:38Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2000, 2016, 2018
@@ -51,7 +51,7 @@ extern "C" {
 #include "DwmSysLogger.hh"
 #include "DwmDnsMessage.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/src/DwmDnsMessage.cc 10150 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/trunk/classes/src/DwmDnsMessage.cc 10150 $");
 
 using namespace std;
 
