@@ -1,5 +1,5 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/src/DwmDnsRRDataMINFO.cc 10133 $
+// @(#) $DwmPath: dwm/DwmDns/trunk/classes/src/DwmDnsRRDataMINFO.cc 10133 $
 // @(#) $Id: DwmDnsRRDataMINFO.cc 10133 2018-01-27 17:41:32Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2000, 2016, 2018
@@ -43,7 +43,7 @@
 #include "DwmDnsLabelSequence.hh"
 #include "DwmDnsRRDataMINFO.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/src/DwmDnsRRDataMINFO.cc 10133 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/trunk/classes/src/DwmDnsRRDataMINFO.cc 10133 $");
 
 using namespace std;
 
