@@ -1,5 +1,5 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/src/DwmDnsRRDataSMIMEA.cc 10075 $
+// @(#) $DwmPath: dwm/DwmDns/trunk/classes/src/DwmDnsRRDataSMIMEA.cc 10075 $
 // @(#) $Id: DwmDnsRRDataSMIMEA.cc 10075 2018-01-25 02:59:37Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2018
@@ -46,7 +46,7 @@
 #include "DwmBase64.hh"
 #include "DwmDnsRRDataSMIMEA.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/src/DwmDnsRRDataSMIMEA.cc 10075 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/trunk/classes/src/DwmDnsRRDataSMIMEA.cc 10075 $");
 
 using namespace std;
 
