@@ -1,5 +1,5 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/src/DwmDnsUtils.cc 10124 $
+// @(#) $DwmPath: dwm/DwmDns/trunk/classes/src/DwmDnsUtils.cc 10124 $
 // @(#) $Id: DwmDnsUtils.cc 10124 2018-01-27 02:06:42Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2018
@@ -47,7 +47,7 @@
 #include "DwmSvnTag.hh"
 #include "DwmDnsUtils.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/src/DwmDnsUtils.cc 10124 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/trunk/classes/src/DwmDnsUtils.cc 10124 $");
 
 using namespace std;
 
