@@ -1,5 +1,5 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/tests/TestDnsMessageQuestion.cc 9996 $
+// @(#) $DwmPath: dwm/DwmDns/trunk/classes/tests/TestDnsMessageQuestion.cc 9996 $
 // @(#) $Id: TestDnsMessageQuestion.cc 9996 2018-01-13 03:24:10Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2018
@@ -43,7 +43,7 @@
 #include "DwmUnitAssert.hh"
 #include "DwmDnsMessageQuestion.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/tests/TestDnsMessageQuestion.cc 9996 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/trunk/classes/tests/TestDnsMessageQuestion.cc 9996 $");
 
 using namespace std;
 using namespace Dwm;
