@@ -44,7 +44,7 @@
 #include "DwmUnitAssert.hh"
 #include "DwmDnsResolvConf.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/tests/TestDnsResolvConf.cc 10030 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/trunk/classes/tests/TestDnsResolvConf.cc 10030 $");
 
 using namespace std;
 using namespace Dwm;
